/**
* File: com.design1online.puzzle.GameLogic.as
* Author: jade@design1online.com
* Created: 12/19/2010
* Purpose: game logic for a demo puzzle game
*	in order to show how embedding works
**/
package com.design1online.puzzle {

	import flash.display.Bitmap;
	import flash.display.MovieClip;
	import flash.display.SimpleButton;
	import flash.events.Event;
	import flash.events.MouseEvent;
	import flash.text.TextField;

	public class GameLogic extends MovieClip {
		
		/**
		* Source: the path to the file containing our square symbol
		* 	which must is relative to where this GameLogic.as file is located
		* Symbol: contains the name you've given the symbol when you chose to 
		*	export it for actionscript
		* Public Var {name}: Finally we associate this symbol to a class named
		*	block. You can call your class whatever you want but you must have a 
		*	different class name for each symbol you're embedding.
		**/
		[Embed(source='../graphics/assets.swf', symbol='squareBlock')] public var Square:Class;
		[Embed(source='../graphics/assets.swf', symbol='interfaceUI')] public var Interface:Class;
		
		public var block = new Square();
		public var ui = new Interface();
		public var score:int;
		
		/**
		* Default Constructor
		**/
		public function GameLogic()
		{
			score = 0;
		}
		
		public function run()
		{
			//add the user interface
			ui.x = 400;
			ui.y = 200;
			ui.btnReset.visible = false;
			ui.addEventListener(MouseEvent.CLICK, mouseClick);
			addChild(ui);
			
			//format the block if necessary
			block.alpha = Math.random();
			block.visible = true;
			block.x = 340;
			block.y = 150;
			block.alpha = 1;
			block.width = block.height = 34;
			block.name = "squareBlock";
			
			//you can even add event listeners to the embedded object
			block.addEventListener(MouseEvent.CLICK, mouseClick);
			
			//now display the block on the screen
			addChild(block);
		}
		
		private function mouseClick(e:Event)
		{
			switch (e.target.name)
			{
				/** 
				* If they click on the block increase their score
				* and update the score text box in the embedded InterfaceUI object
				* then reset the block
				**/
				case "squareBlock":
					//check to see if the instructions are still up
					if (ui.instructions_txt.visible)
					{
						score = 0;
						ui.instructions_txt.visible = false;
						ui.btnStart.visible = false;
						ui.btnReset.visible = true;
						resetBlock();
					}
					//they are actively playing the game
					else 
					{
						score++;
						ui.score_txt.text = score;
						resetBlock();
					}
				break;
					
				/**
				* If they hit the reset button on the ui screen
				* it will be caught here and restart the game
				**/
				case "btnReset":
					score = 0;
					ui.score_txt.text = score;
					resetBlock();
				break;
				
				/** 
				* If they hit the start button or the instructions screen hide 
				* the instructions screen and start the game
				**/
				case "btnStart":
					ui.instructions_txt.visible = false;
					ui.btnStart.visible = false;
					ui.btnReset.visible = true;
					resetBlock();
				break;
			}
		}
		
		/**
		* Purpose: scramble the blocks opacity, size and position
		**/
		private function resetBlock()
		{
			block.x = (Math.random() * 600);
			block.y = (Math.random() * 400);
			block.alpha = Math.random();
		}
		
	}
}